import { Component } from '@angular/core';
import { FormBuilder, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { MatButton, MatFabButton, MatMiniFabButton } from '@angular/material/button';
import { MatFormField, MatLabel, MatSuffix } from '@angular/material/form-field';
import { MatIcon } from '@angular/material/icon';
import { MatInput } from '@angular/material/input';
import { MatCell, MatCellDef, MatColumnDef, MatHeaderCell, MatHeaderCellDef, MatHeaderRow, MatHeaderRowDef, MatRow, MatRowDef, MatTable, MatTableDataSource } from '@angular/material/table';
import { ActivatedRoute } from '@angular/router';
import { Employee, EmployeeService, Qualification } from '@core/ems';

@Component({
    selector: 'app-employee-detail',
    imports: [
        MatButton,
        ReactiveFormsModule,
        MatFormField,
        MatLabel,
        MatInput,
        MatIcon,
        MatSuffix,
        MatTable,
        MatHeaderRowDef,
        MatRowDef,
        MatColumnDef,
        MatHeaderCellDef,
        MatCell,
        MatCellDef,
        MatHeaderCell,
        MatHeaderRow,
        MatRow,
        MatMiniFabButton,
    ],
    templateUrl: './employee-detail.component.html',
    styleUrl: './employee-detail.component.scss'
})
export class EmployeeDetailComponent {
    isNewEmployee: boolean;
    employeeForm: FormGroup;
    skillsDataSource: MatTableDataSource<Qualification> = new MatTableDataSource<Qualification>([]);
    skillsDisplayedColumns = ['skill', 'action'];

    constructor(
        private route: ActivatedRoute,
        private employeeService: EmployeeService,
        private formBuilder: FormBuilder
    ) {
        const idParam = this.route.snapshot.paramMap.get('id');
        this.isNewEmployee = idParam == null;

        this.employeeForm = this.formBuilder.group<Employee>({
            id: 0,
            firstName: '',
            lastName: '',
            postcode: '',
            city: '',
            street: '',
            phone: '',
            skillSet: []
        });

        if (this.isNewEmployee) {
            return;
        }

        const id = parseInt(idParam as string);
        this.employeeService.getEmployee({ id }).subscribe((employee) => {
            this.employeeForm = this.formBuilder.group<Employee>(employee);
            this.skillsDataSource = new MatTableDataSource<Qualification>(employee.skillSet);
        });



    }

    onAbort() {

    }

    onCreate() {

    }

    onSave() {

    }
}
